package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class CertificationRequest extends ASN1Encodable {
   protected CertificationRequestInfo reqInfo = null;
   protected AlgorithmIdentifier sigAlgId = null;
   protected DERBitString sigBits = null;

   public static CertificationRequest getInstance(Object o) {
      if (o instanceof CertificationRequest) {
         return (CertificationRequest)o;
      } else if (o instanceof ASN1Sequence) {
         return new CertificationRequest((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   protected CertificationRequest() {
   }

   public CertificationRequest(CertificationRequestInfo requestInfo, AlgorithmIdentifier algorithm, DERBitString signature) {
      this.reqInfo = requestInfo;
      this.sigAlgId = algorithm;
      this.sigBits = signature;
   }

   public CertificationRequest(ASN1Sequence seq) {
      this.reqInfo = CertificationRequestInfo.getInstance(seq.getObjectAt(0));
      this.sigAlgId = AlgorithmIdentifier.getInstance(seq.getObjectAt(1));
      this.sigBits = (DERBitString)seq.getObjectAt(2);
   }

   public CertificationRequestInfo getCertificationRequestInfo() {
      return this.reqInfo;
   }

   public AlgorithmIdentifier getSignatureAlgorithm() {
      return this.sigAlgId;
   }

   public DERBitString getSignature() {
      return this.sigBits;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.reqInfo);
      var1.add(this.sigAlgId);
      var10000.add(this.sigBits);
      return new DERSequence(var1);
   }
}
